@@ -450,7 +450,7 @@ class VirtualService(HttpClient, KempBaseObjectModel):
 
     def save(self, update=False):
         if not update:
-            response = self._get("/addvs", self._get_base_parameters())
+            response = self._get("/addvs", self.to_api_dict())
         else:
             response = self._get("/modvs", self.to_api_dict())
         if is_successful(response):
